@@ -1,14 +1,12 @@
 package Rose::DBx::TestDB;
 
-# inspired by DBICx::TestDatabase
-
 use warnings;
 use strict;
 use File::Temp 'tempfile';
 use Rose::DB;
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 my @TMPFILES;
 
@@ -118,6 +116,8 @@ L<http://search.cpan.org/dist/Rose-DBx-TestDB>
 
 =head1 ACKNOWLEDGEMENTS
 
+Inspired by DBICx::TestDatabase.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2007 Peter Karman, all rights reserved.
